<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Carbain Frédéric <fcarbain@yahoo.fr>
 * @author Nicolas Friedli <nicolas@theologique.ch>
 * @author Schplurtz le Déboulonné <Schplurtz@laposte.net>
 */
$lang['menu']                  = 'Paramètres de style du thème (template)';
$lang['js']['loader']          = 'La prévisualisation est en chargement... <br />Si rien ne se passe, les données sont peut-être erronées';
$lang['js']['popup']           = 'Ouvrir dans une nouvelle fenêtre';
$lang['error']                 = 'Désolé, ce thème n\'utilise pas cette fonctionnalité.';
$lang['btn_preview']           = 'Aperçu des changements';
$lang['btn_save']              = 'Sauvegarder les changements.';
$lang['btn_reset']             = 'Remettre les changements courants à zéro';
$lang['btn_revert']            = 'Remettre les styles du thème aux valeurs par défaut';
$lang['__text__']              = 'Couleur de texte principale';
$lang['__background__']        = 'Couleur de fond principale';
$lang['__text_alt__']          = 'Couleur de texte alternative';
$lang['__background_alt__']    = 'Couleur de fond alternative';
$lang['__text_neu__']          = 'Couleur de texte neutre';
$lang['__background_neu__']    = 'Couleur de fond neutre';
$lang['__border__']            = 'Couleur des contours';
$lang['__highlight__']         = 'Couleur de surbrillance (utilisée pincipalement pour les résultats de recherche)';
